@@ -24,3 +24,7 @@ class ErrorMessages(object):
     AUDIENCE_DOWNLOAD_MISSING_ARGUMENT = "download() missing 1 required positional argument: 'requestId'"
 
     VERIFICATION_EMAIL_MISSING_ARGUMENT = "email() missing 1 required positional argument: 'email'"
+
+    PERMISSION_CREATE_MISSING_REQUIRED_FIELDS = "For Permission Create query, consentPurposes,policyUrl,termsService,collectionMethod,collectionLocation,query are required."
+    PERMISSION_DELETE_MISSING_REQUIRED_FIELDS = "No queryable inputs given (for example: email, emails, phone, phones, location, name, profiles, maids, li_nonid, partnerId, recordId, personId)"
+    PERMISSION_VERIFY_MISSING_REQUIRED_FIELDS = "For Permission Verify query, purposeId,channel,query are required."
